import pandas as pd
import pyarrow.parquet as pq
# Leer el archivo Parquet con pandas
parquet ="C:\\Users\\e-ajuareza\\Documents\\Yastas\\yas-cierre-sii\\params\\streaming\\parquet\\trn_streaming_movimientos-00000-of-00001.parquet"
df = pd.read_parquet(parquet)

# Obtener los tipos de datos de cada columna
tipos_de_datos = df.dtypes

# Imprimir los tipos de datos
for columna, tipo_dato in tipos_de_datos.iteritems():
    print(f"Columna: {columna}, Tipo de dato: {tipo_dato}")


from data_code.gcp.secrets import get_secret
import psycopg2

class Database():
    """_summary_

    Args:
        Proxy (Proxy): _description_
    """
    def __init__(self, host, port, database, secret_user, secret_pswd, project_id):
        self.host = host
        self.port = port
        self.database_name = database
        user = get_secret(secret_user,project_id)
        password = get_secret(secret_pswd,project_id)
        self.user = user
        self.password = password
        
    def get_connection(self):
        # Establecer la conexión con la base de datos
        connection = psycopg2.connect(
            host=self.host,
            port=self.port, 
            database=self.database_name,
            user=self.user,
            password=self.password
        )
        return connection
    
    def get_tables(self, connection):

        # Crear un cursor para ejecutar consultas
        cursor = connection.cursor()
        

        # Obtener los nombres de las tablas
        cursor.execute("""
                    SELECT table_name
                    FROM information_schema.tables
                    WHERE table_schema = 'public'
                    ORDER BY table_name
                    """)

        # Obtener los resultados
        filas = cursor.fetchall()

        # Procesar los resultados
        tablen="Tablenames"
        print(f"\n/ {tablen.upper():^20} \\")
        print("~~~~~~~~~~~~~~~~~~~~~~~~")
        
        for fila in filas:
            print(f"| {fila[0]:^20} |")
            print("________________________")
        print("\n")
        # Cerrar el cursor y la conexión
        #cursor.close()
        
    def execute_query(self, connection, query:str):

        # Crear un cursor para ejecutar consultas
        cursor = connection.cursor()

        # Ejecutar una consulta de ejemplo
        cursor.execute(query)
        schema = cursor.description

        # Obtener los resultados de la consulta
        query_result = cursor.fetchall()

        # Procesar los resultados
        # for fila in filas:
        #     print(fila)

        # Cerrar el cursor y la conexión
        cursor.close()
        return schema, query_result

    def close_connection(self, connection):
        # Cerrar el cursor y la conexión
        connection.close()


from data_code.utils.appearence import highlight_text
import subprocess

def evaluate_response(response: subprocess.CompletedProcess) -> str:
    if response.returncode == 0:
        message = "Dataflow template has been created successfully."
    else:
        message = (
            f"It couldn't be completed\n"
            f"It finished with response: {response.returncode}\n"
            f"Command error output:\n\n{highlight_text(response.stderr.decode('utf-8'),31)}"
        )
        raise ValueError(message)
    return message


import pandas as pd

def parquet_csv(parquet_file, csv_file):

    # Leer el archivo Parquet en un DataFrame de pandas
    df = pd.read_parquet(parquet_file)
    print(df)
    # Guardar el DataFrame en formato CSV
    df.to_csv(csv_file, index=False)
    
env="dev"
domain="AB"
table="streaming_movimientos"
step="raw"
root_parquet = f"gs://yas-sii-inp-ext-{step}-{env}"
parquet_query = f"{root_parquet}/{domain}/parquet_schema/parquet-schema-{domain}-{step}-{table}-00000-of-00001.txt"
parquet_raw = f"{root_parquet}/{domain}/{step}_{table}-00000-of-00001.parquet"
print(f"query: {parquet_query}\n raw: {parquet_raw}" )